#!/bin/bash
#
# source: http://hal.freedesktop.org/releases/eggdbus-0.6.tar.gz
#
# maintainer: (package seek a maintainers)
#

#------------------ Set Some Variables

soft='eggdbus'
softversion='0.6'
arch="i486"
cpu="i686"
packageversion="64.2"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# ----------------- Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src

chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --disable-static

make -j2
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

gzip -9 $dest/usr/man/man?/*.?

# Documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING HACKING INSTALL NEWS README $dest/usr/doc/$soft-$softversion

mkdir -p $dest/install
cat << "EODESC" > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

       |-----handy-ruler---------------------------------------------------------|
eggdbus: eggdbus - is a D-Bus bindings for GObject
eggdbus:
eggdbus: EggDBus aims to be an easy-to-use set of GObject bindings fo interacting
eggdbus: with DBus.  Currently, this interaction is done using libdbus-1 but that
eggdbus: is subject to change
eggdbus:
eggdbus:
eggdbus:
eggdbus:
eggdbus:
eggdbus:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5
